<template>
  <PageWrapper :title="t('仓库')">
    <CollapseContainer :title="t('配置参数')">
      <BasicForm @register="register" @submit="handleSubmit" />
    </CollapseContainer>
  </PageWrapper>
</template>
<script lang="ts">
import { defineComponent, onMounted, unref } from 'vue';
import { BasicForm, FormSchema, useForm } from '/@/components/Form/index';
import { CollapseContainer } from '/@/components/Container';
import { useMessage } from '/@/hooks/web/useMessage';
import { PageWrapper } from '/@/components/Page';
import { SaveWareHouse } from '/@/api/tigerapi/wms/house';
import { getTreeList } from '/@/api/tigerapi/dept';
//import  WhListItem  from '@/api/model/warehoueseModel';
import { useI18n } from '/@/hooks/web/useI18n';
const { t } = useI18n('WMS.WareHouse');
const schemas: FormSchema[] = [
{
      field: 'CREATE_TIME',
      component: 'Input',
      label: '创建时间',
      colProps: {
        span: 24,
      },
      show:false
    },
    {
      field: 'CREATE_USER',
      component: 'Input',
      label: '创建人',
      colProps: {
        span: 24,
      },
      show:false
    },
    {
      field: 'UPDATE_TIME',
      component: 'Input',
      label: '修改时间',
      colProps: {
        span: 24,
      },
      show:false
    },
    {
      field: 'UPDATE_USER',
      component: 'Input',
      label: '修改人',
      colProps: {
        span: 24,
      },
      show:false
    },
    
  {
    field: 'WH_CODE',
    component: 'Input',
    label: t('仓库代码'),
    colProps: {
      span: 8,
    },
    dynamicDisabled: true,
    required: true,
  },
  {
    field: 'WH_NAME',
    component: 'Input',
    label: t('仓库名称'),
    colProps: {
      span: 8,
    },
    required: true,
  },
  {
    field: 'REMARK',
    component: 'Input',
    label: t('备注'),
    colProps: {
      span: 8,
    },
    required: false,
  },
  {
    field: 'TRANSFER_WH',
    component: 'Input',
    label: t('默认调拨T100库位'),
    colProps: {
      span: 8,
    },
    required: false,
  },
  {
    field: 'ID',
    label: 'ID',
    required: true,
    defaultValue: 0,
    component: 'InputNumber',
    show: false,
  },
  {
    field: 'IS_ACTIVE',
    component: 'RadioGroup',
    label: t('是否启用'),
    colProps: {
      span: 8,
    },
    required: true,
    componentProps: {
      options: [
        {
          label: 'Y',
          value: 'Y',
        },
        {
          label: 'N',
          value: 'N',
        },
      ],
    },
    rules: [{ required: false, message: t('覆盖默认生成的校验信息')}],
  },
  {
    field: 'AUTH_ORG',
    label: t('据点'),
    component: 'TreeSelect',
    colProps: {
      span: 8,
    },
    componentProps: {
      fieldNames: {
        label: 'deptName',
        key: 'deptCode',
        value: 'deptCode',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
  // {
  //   field: 'SCAN_AF_CUT',
  //   component: 'RadioGroup',
  //   label: t('是否截料重扫'),
  //   colProps: {
  //     span: 8,
  //   },
  //   required: true,
  //   componentProps: {
  //     options: [
  //       {
  //         label: 'Y',
  //         value: 'Y',
  //       },
  //       {
  //         label: 'N',
  //         value: 'N',
  //       },
  //     ],
  //   },
  //   rules: [{ required: false, message: t('覆盖默认生成的校验信息')}],
  // },
];

export default defineComponent({
  components: { BasicForm, CollapseContainer, PageWrapper },
  props: {
    data: {
      type: Object,
      //default: () => ({}),
    }
  },
  emit: ['success', 'register'],
  setup(props, { emit }) {
    const { createMessage } = useMessage();
    const [
      register,
      { validateFields, clearValidate, getFieldsValue, updateSchema, resetFields, setFieldsValue },
    ] = useForm({
      submitButtonOptions: { text: t('保存') },
      showResetButton: false,
      labelWidth: 120,
      schemas,
      actionColOptions: {
        span: 24,
      },
    });
    async function validateForm() {
      try {
        const res = await validateFields();
        console.log('passing', res);
      } catch (error) {
        console.log('not passing', error);
      }
    }
    async function resetValidate() {
      clearValidate();
    }
    function getFormValues() {
      const values = getFieldsValue();
      createMessage.success('values:' + JSON.stringify(values));
    }
    // 自动请求并暴露内部方法
    onMounted(() => {
      setFormValues()
    });
    async function setFormValues() {
      setFieldsValue({
        CREATE_USER: props.data[0].CREATE_USER,
        CREATE_TIME:props.data[0].CREATE_TIME,
        GHOST_ROW: false,
        ID: props.data[0].ID,
        IS_ACTIVE: props.data[0].IS_ACTIVE,
        AUTH_ORG: props.data[0].AUTH_ORG,
        REMARK: props.data[0].REMARK,
        TRANSFER_WH: props.data[0].TRANSFER_WH,
        SHORT_NAME: "",
        UPDATE_TIME: props.data[0].UPDATE_TIME,
        UPDATE_USER: null,
        WH_ADDRESS: "",
        WH_AREA: "",
        WH_CODE: props.data[0].WH_CODE,
        WH_CONTACT: "",
        WH_NAME: props.data[0].WH_NAME,
        WH_TEL: "",
        key: props.data[0].key
        //SCAN_AF_CUT:props.data[0].SCAN_AF_CUT
      });
      const treeData = await getTreeList();
      updateSchema([
        {
          field: 'USER_PWD',
          show: !unref(false),
        },
        {
          field: 'AUTH_ORG',
          componentProps: { treeData },
        },
      ]);

    }


    //提交
    function handleSubmit(values: any) {
      //createMessage.success('click search,values:' + JSON.stringify(values));
      const apiAction = SaveWareHouse(values, true)
      apiAction.then((action) => {
        if (action.IsSuccessed) {
          createMessage.success(values.WH_CODE + t('保存成功'));
          emit('success', {
            isUpdate: unref(false),
            values: { ...values, id: 0 },
          });
        } else {
          createMessage.error(values.WH_CODE + t('保存失败'));
        }
      })
    }
    return {
      register,
      schemas,
      handleSubmit,
      getFormValues,
      setFormValues,
      validateForm,
      resetValidate,
      resetFields,
      props,
      t
    };
  },
});
</script>
